@@ -23,20 +23,7 @@ import pandas as pd
 from skimage import io
 from tqdm import tqdm
 
-
-def def_pwd(path):
-    """check path, if not exists, make it"""
-    if path is None:
-        path = os.getcwd()
-
-    if os.path.exists(path):
-        os.chdir(path)
-    else:
-        os.makedirs(path)
-        os.chdir(path)
-    pwd = os.getcwd()
-    locals()[pwd] = pwd
-    return pwd
+from mgetool.tool import def_pwd
 
 
 class Store(object):
@@ -137,7 +124,9 @@ class Store(object):
 
         self._filename = file_new_name or self.default_filename
 
-        if os.path.isfile('{}{}.{}'.format(self._prefix, self._filename, suffix)) and mode == "n":
+        if "." + suffix in self._filename:
+            self._filename = self._filename.replace("." + suffix, "")
+        if os.path.isfile('{}{}'.format(self._prefix, self._filename, suffix)) and mode == "n":
             shu1 = 1
             while os.path.isfile('{}{}({}).{}'.format(self._prefix, self._filename, shu1, suffix)):
                 shu1 += 1
